@@ -23,3 +23,12 @@ class FourLetterCmdsTestCase(ShellTestCase):
         """ test dump """
         self.shell.onecmd("dump")
         self.assertIn("127.0.0.1", self.output.getvalue())
+
+    def test_disconnected(self):
+        """ test mntr """
+        self.shell.onecmd("disconnect")
+        self.shell.onecmd("mntr")
+        self.shell.onecmd("cons")
+        self.shell.onecmd("dump")
+        expected_output = u'Not connected and no host given.\n' * 3
+        self.assertEquals(expected_output, self.output.getvalue())
